/**
 * Whiteboard session manager
 * Inkboard message context definitions
 *
 * Authors:
 * David Yip <yipdw@rose-hulman.edu>
 *
 * Copyright (c) 2005 Authors
 *
 * Released under GNU GPL, read the file 'COPYING' for more information
 */

#ifndef __WHITEBOARD_MESSAGE_CONTEXTS_H__
#define __WHITEBOARD_MESSAGE_CONTEXTS_H__

#include "jabber_whiteboard/typedefs.h"

namespace Inkscape {

namespace Whiteboard {

void initialize_received_message_contexts(MessageContextMap& mcm);

}

}

#endif

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
